import { ComponentRef, ElementRef, EventEmitter, ViewContainerRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { PdfViewerComponent } from 'ng2-pdf-viewer';
import { TextOptionsComponent } from './components/text-options/text-options.component';
import { CommentSelection } from './models/comment-selection.model';
import { SpanLocation } from './models/span-location.model';
import { HighlightSelection } from './models/highlight.model';
import { TagSelection } from './models/tag-selection.model';
import { HighlightPipe } from './pipes/highlight.pipe';
import { Nullable } from './types/types';
import * as i0 from "@angular/core";
export declare class MoPdfViewerComponent {
    private readonly router;
    private readonly route;
    private readonly viewContainerRef;
    elementRef: ElementRef;
    pdfSrc: string | Uint8Array;
    documentTitle: string;
    documentClassification: string;
    documentAuthor: string;
    minimalView: boolean;
    pdfComponent: PdfViewerComponent;
    currentSearchIndex: number;
    totalMatchesCount: number;
    I: {
        faFile: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faUser: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faSliders: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faBookOpenReader: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faMessage: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faQuoteRight: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faArrowTrendUp: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faThumbsUp: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faTag: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faTrash: import("@fortawesome/fontawesome-common-types").IconDefinition;
        faHighlighter: import("@fortawesome/fontawesome-common-types").IconDefinition;
    };
    searchText: string;
    results: {
        label: string;
    }[];
    comments: CommentSelection[];
    spanCommentsMap: Map<Element, Set<string>>;
    highlights: HighlightSelection[];
    spanHighlightsMap: Map<Element, Set<string>>;
    tags: TagSelection[];
    spanTagMap: Map<Element, Set<string>>;
    searchCategories: {
        label: string;
        icon: import("@fortawesome/fontawesome-common-types").IconDefinition;
    }[];
    navs: ({
        id: string;
        label: string;
        background: string;
        foreground: string;
    } | {
        id: string;
        label: string;
        background: string;
        foreground: string;
    } | {
        id: string;
        label: string;
        background: string;
        foreground: string;
    })[];
    activeNav: {
        id: string;
        label: string;
        background: string;
        foreground: string;
    } | {
        id: string;
        label: string;
        background: string;
        foreground: string;
    } | {
        id: string;
        label: string;
        background: string;
        foreground: string;
    };
    closePane: EventEmitter<any>;
    activeNavChange: EventEmitter<string>;
    selectedSearchCategory: string;
    page: number;
    highlightPipe: HighlightPipe;
    componentRefs: ComponentRef<TextOptionsComponent>[];
    dropdownVisible: {
        [key: string]: boolean;
    };
    constructor(router: Router, route: ActivatedRoute, viewContainerRef: ViewContainerRef, elementRef: ElementRef);
    afterLoadComplete(): void;
    selectSearchCategory(category: string): void;
    onKeyUp(event: KeyboardEvent): void;
    search(stringToSearch: string): void;
    searchUp(stringToSearch: string): void;
    searchDown(stringToSearch: string): void;
    updateSearch(stringToSearch: string, findPrevious: boolean): void;
    submitComment(comment: CommentSelection, submitButton: HTMLButtonElement): void;
    enableSubmitButton(comment: CommentSelection, submitButton: HTMLButtonElement): void;
    editComment(comment: CommentSelection): void;
    closeSource(): void;
    showOptions(event: MouseEvent): void;
    setClassesForComments(): void;
    setClassesForHighlights(): void;
    setClassesForTags(): void;
    deleteAllComponentRef(): void;
    findRangeSections(selection: Selection): SpanLocation[];
    getFirstPage(selection: {
        spanLocations: SpanLocation[];
    }): Nullable<number>;
    getFirstSpan(selection: {
        spanLocations: SpanLocation[];
    }): Nullable<number>;
    removeHighlight(highlight: HighlightSelection): void;
    setClassesForItem(item: {
        id: string;
        spanLocations: SpanLocation[];
    }, list: {
        id: string;
        spanLocations: SpanLocation[];
    }[], htmlClass: string, selectionMap: Map<Element, Set<string>>, selection: Selection): void;
    sortSelection(a: {
        spanLocations: SpanLocation[];
    }, b: {
        spanLocations: SpanLocation[];
    }): number;
    removeComment(comment: CommentSelection): void;
    goToSelection(selection: {
        spanLocations: SpanLocation[];
    }): void;
    selectSelection(selection: {
        spanLocations: SpanLocation[];
    }): void;
    removeSelection(selection: {
        spanLocations: SpanLocation[];
    }, htmlClass: string, selectionId: string, selectionMap: Map<Element, Set<string>>): void;
    removeTag(tag: TagSelection): void;
    getSpanFromLocation(location: SpanLocation): Nullable<Element>;
    setSpanClassFromLocationMapped(location: SpanLocation, htmlClass: string, selectionId: string, selectionMap: Map<Element, Set<string>>): void;
    setSpanClassFromLocation(location: SpanLocation, htmlClass: string): void;
    removeSpanClassFromLocation(location: SpanLocation, htmlClass: string, selectionId: string, selectionMap: Map<Element, Set<string>>): void;
    getSpanLocation(startContainer: Node): SpanLocation;
    getInterveningTextLayers(startPage: number, endPage: number): Element[];
    getInterveningLocations(startLocation: SpanLocation, endLocation: SpanLocation): SpanLocation[];
    getAllNonSamePageLocations(startLocation: SpanLocation, endLocation: SpanLocation): SpanLocation[];
    getStartPageLocations(startLocation: SpanLocation): SpanLocation[];
    getAllLocationsOnPage(pageNumber: number): SpanLocation[];
    getEndPageLocations(endLocation: SpanLocation): SpanLocation[];
    getSamePageLocations(startLocation: SpanLocation, endLocation: SpanLocation): SpanLocation[];
    getTextLayerFromLocation(pageNumber: number): Nullable<Element> | undefined;
    getMiddlePages(startPage: HTMLElement | null, endPage: HTMLElement | null): HTMLElement[];
    getPageParent(node: Node): Nullable<HTMLElement>;
    getSpan(node: Node): Nullable<HTMLElement>;
    commntDropdownVisible(element: HTMLElement): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MoPdfViewerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MoPdfViewerComponent, "mo-pdf-viewer", never, { "pdfSrc": { "alias": "pdfSrc"; "required": true; }; "documentTitle": { "alias": "documentTitle"; "required": false; }; "documentClassification": { "alias": "documentClassification"; "required": false; }; "documentAuthor": { "alias": "documentAuthor"; "required": false; }; "minimalView": { "alias": "minimalView"; "required": false; }; "activeNav": { "alias": "activeNav"; "required": false; }; }, { "closePane": "closePane"; "activeNavChange": "activeNavChange"; }, never, never, true, never>;
}
